Author: Ed Grossman
Description: The official web site of the Vermont Judicial System, with on-line Vermont Court forms and Vermont Legal Resources.
Keywords: Vermont Judicial System, Vermont Court Forms, Vermont Legal Resources, Vermont Supreme Court, State Court, Court

| Turn on more accessible mode Skip to main content
Turn off more accessible mode # Legal Community

##
| ### Quick Launch View All Site Content
Legal Information
Administrative Order No. 9
Annual Reports of the PRB
Attorney Discipline Information
Attorney Licensing (Including Pro Hac Vice)
Bar Admissions
Complaint Brochure
Civil Division Opinions
Environmental Division Opinions
Judicial Conduct Board
Legal Links (Including Statutes and Rules)
Mandatory Continuing Legal Education
Memos to the Bar
Policies
Preliminary Evaluators
Proposed and Promulgated Rules
Professional Responsibility Board Decisions
Supreme Court Decisions
Supreme Court Oral Arguments
Trust Account Manual
VT Rules of Professional Conduct
Vermont Supreme Court Published Opinions and Entry Orders The Vermont Supreme Court issues opinions on Fridays. The opinions are posted by 11 a.m. EST/EDT. To view an opinion, click on the year of decision and then select the title of the opinion you wish to view.
# of Decisions |
Issued On |
3 |
| 10/16/2015
View in Web Browser | /_layouts/images/ichtmxls.gif | /LC/_layouts/xlviewer.aspx?listguid={ListId}&itemid={ItemId}&DefaultItemOpen=1 | 0x0 | 0x1 | FileType | xlsx | 255
View in Web Browser | /_layouts/images/ichtmxls.gif | /LC/_layouts/xlviewer.aspx?listguid={ListId}&itemid={ItemId}&DefaultItemOpen=1 | 0x0 | 0x1 | FileType | xlsb | 255
Snapshot in Excel | /_layouts/images/ewr134.gif | /LC/_layouts/xlviewer.aspx?listguid={ListId}&itemid={ItemId}&Snapshot=1 | 0x0 | 0x1 | FileType | xlsx | 256
Snapshot in Excel | /_layouts/images/ewr134.gif | /LC/_layouts/xlviewer.aspx?listguid={ListId}&itemid={ItemId}&Snapshot=1 | 0x0 | 0x1 | FileType | xlsb | 256
File Name | Case Name | Public Domain # | Supreme Court Docket # | Date Issued
--- | --- | --- | --- | ---
Year Published: 2015
op14-301.pdf | Everbank, Successor by Assignment to Bank of America, N.A. | 2015 VT 131 | 2014-301 | 10/16/2015
op15-083.pdf | In re Application of Beach Properties, Inc. d/b/a Basin Harbor Club, for a Certificate of Public Good for an Interconnected Group Net-Metered Photovoltaic Electric Power System | 2015 VT 130 | 2015-083 | 10/16/2015
op15-092.pdf | Kenneth P. Felis v. Downs Rachlin Martin, PLLC, and Gallagher, Flynn & Company, LLP | 2015 VT 129 | 2015-092 | 10/16/2015
op14-382.pdf | Dow Tillson and Susan Tillson v. Richard A. Lane, M.D. and Lane Eye Associates | 2015 VT 121 | 2014-382 | 10/9/2015
op14-434.pdf | In re Bove Demolition/Construction Application (Richard J. Bove, Sr. and Rick Bove, Appellants) | 2015 VT 123 | 2014-434 | 10/9/2015
op14-463.pdf | Amy Labate & Robert Labate, Individually and On Behalf of Minor Daughter, J.L. v. Rutland Hospital, Inc. d/b/a Rutland Regional Medical Center and Santiago Cancio-Bello, M.D. | 2015 VT 128 | 2014-463 | 10/2/2015
op15-144.pdf | In re M.M. and C.M., Juveniles | 2015 VT 122 | 2015-144 | 10/2/2015
op14-207.pdf | State v. Eric K. Manning | 2015 VT 124 | 2014-207 | 10/2/2015
eo15-331.bail.pdf | State v. Evan P. Ford | 2015 VT 127 | 2015-331 | 9/29/2015
op14-388.pdf | Connie C. Simendinger v. William Simendinger | 2015 VT 118 | 2014-388 | 9/18/2015
op15-170.pdf | In re M.O., Juvenile | 2015 VT 120 | 2015-170 | 9/18/2015
op14-275.pdf | Janet McKinstry & Mark McKinstry | 2015 VT 125 | 2014-275 | 9/18/2015
op14-196.pdf | State v. Kent Richland, Jr. | 2015 VT 126 | 2014-196 | 9/18/2015
op15-035.pdf | Michael Bandler, MB&Co, Ltd. a/k/a Michael Bandler & Company v. Cohen Rosenthal & Kramer, LLP | 2015 VT 115 | 2015-035 | 9/11/2015
op14-108.pdf | Roxanne Moran v. Vermont State Retirement Board and Vermont State Treasurer | 2015 VT 119 | 2014-108 | 9/11/2015
op14-292.pdf | State v. William O. Stanley, Sr. | 2015 VT 117 | 2014-292 | 9/11/2015
op13-477.pdf | State v. Adam Winters | 2015 VT 116 | 2013-477 | 9/4/2015
op14-020.pdf | State v. Billy Joe Putnam | 2015 VT 113 | 2014-020 | 9/4/2015
op14-363.pdf | In re A.M., Juvenile | 2015 VT 109 | 2014-363 | 8/28/2015
op14-160.pdf | James LeBlanc, Christine LeBlanc Fortin, David LeBlanc and Herman LeBlanc v. Robert E. Snelgrove | 2015 VT 112 | 2014-160 | 8/28/2015
op14-055.pdf | State v. David Tracy | 2015 VT 111 | 2014-055 | 8/28/2015
eo15-274.bail.pdf | State v. James Cushing | 2015 VT 114 | 2015-274 | 8/25/2015
op14-352.pdf | In re Champlain Parkway Act 250 Permit (Fortieth Burlington LLC, Appellant) | 2015 VT 105 | 2014-352 | 8/21/2015
op15-003.pdf | Juanita Burch-Clay v. Debra J. Taylor, Individually and In Her Capacity as Superintendent of Schools, Rutland Central Supervisory Union | 2015 VT 110 | 2015-003 | 8/21/2015
op14-390.pdf | Kathleen Vanderbloom v. State of Vermont, Agency of Transportation | 2015 VT 103 | 2014-390 | 8/21/2015
op14-240.pdf | David A. Gauthier v. Keurig Green Mountain, Inc. f/k/a Green Mountain Coffee Roasters, Inc. | 2015 VT 108 | 2014-240 | 8/14/2015
op14-373.pdf | In re Cherie Hyde | 2015 VT 106 | 2014-373 | 8/14/2015
op14-246.pdf | In re Derrick Brown | 2015 VT 107 | 2014-246 | 8/14/2015
op14-419.pdf | State v. Kelly M. Taylor | 2015 VT 104 | 2014-419 | 8/14/2015
op14-121.pdf | State v. Leo Paul Pratt II | 2015 VT 89 | 2014-121 | 8/14/2015
op13-480.pdf | State v. Timothy P. Perley | 2015 VT 102 | 2013-480 | 8/14/2015
eo15-258.pdf | In re PRB Docket No. 2015.002 | 2015 VT 101 | 2015-258 | 8/11/2015
op14-087.pdf | Equinox on the Battenkill Management Assn., Inc. v. Philadelphia Indemnity Ins. Co. | 2015 VT 98 | 2014-087 | 8/7/2015
op15-019.pdf | In re R.B., O.B. and K.C., Juveniles | 2015 VT 100 | 2015-019 | 8/7/2015
op14-410.pdf | State v. Paul Aiken | 2015 VT 99 | 2014-410 | 8/7/2015
op14-300.pdf | State v. David Wisowaty | 2015 VT 97 | 2014-300 | 7/24/2015
op14-269.pdf | State v. Salahdin Trowell | 2015 VT 96 | 2014-269 | 7/24/2015
op14-339.pdf | Brice Kirkland and Gordon Kirkland v. James Kolodziej and Barbara Kolodziej | 2015 VT 90 | 2014-339 | 7/17/2015
op15-022.pdf | In re J.M., Juvenile | 2015 VT 94 | 2015-022 | 7/17/2015
op14-190.pdf | In re North East Materials Group LLC ACT 250 JO #5-21 (Russell Austin, Pamela Austin, Julie Barre, Marc Bernier, et al., Appellants) | 2015 VT 79 | 2014-190 | 7/17/2015
op14-283.pdf | In re Stephanie H. Taylor, M.D. | 2015 VT 95 | 2014-283 | 7/17/2015
op13-201A.amended.pdf | State v. Scott Provost | 2014 VT 86A | 2013-201 | 7/17/2015

| Sign In |  |